from typing import overload
import Calculators
import System


class SecurityType(System.Enum):
    """This class has no documentation."""

    # Cannot convert to Python: None = 0

    Spot = 1

    Futures = 2


